Class: Aws::ChimeSDKVoice::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ChimeSDKVoice::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chimesdkvoice/client.rb,
sig/client.rbs
Overview
An API client for ChimeSDKVoice. To construct a client, you need to configure a :region and :credentials.
client = Aws::ChimeSDKVoice::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociatePhoneNumbersWithVoiceConnectorGroupResponseSuccess, _AssociatePhoneNumbersWithVoiceConnectorResponseSuccess, _BatchDeletePhoneNumberResponseSuccess, _BatchUpdatePhoneNumberResponseSuccess, _CreatePhoneNumberOrderResponseSuccess, _CreateProxySessionResponseSuccess, _CreateSipMediaApplicationCallResponseSuccess, _CreateSipMediaApplicationResponseSuccess, _CreateSipRuleResponseSuccess, _CreateVoiceConnectorGroupResponseSuccess, _CreateVoiceConnectorResponseSuccess, _CreateVoiceProfileDomainResponseSuccess, _CreateVoiceProfileResponseSuccess, _DisassociatePhoneNumbersFromVoiceConnectorGroupResponseSuccess, _DisassociatePhoneNumbersFromVoiceConnectorResponseSuccess, _GetGlobalSettingsResponseSuccess, _GetPhoneNumberOrderResponseSuccess, _GetPhoneNumberResponseSuccess, _GetPhoneNumberSettingsResponseSuccess, _GetProxySessionResponseSuccess, _GetSipMediaApplicationAlexaSkillConfigurationResponseSuccess, _GetSipMediaApplicationLoggingConfigurationResponseSuccess, _GetSipMediaApplicationResponseSuccess, _GetSipRuleResponseSuccess, _GetSpeakerSearchTaskResponseSuccess, _GetVoiceConnectorEmergencyCallingConfigurationResponseSuccess, _GetVoiceConnectorExternalSystemsConfigurationResponseSuccess, _GetVoiceConnectorGroupResponseSuccess, _GetVoiceConnectorLoggingConfigurationResponseSuccess, _GetVoiceConnectorOriginationResponseSuccess, _GetVoiceConnectorProxyResponseSuccess, _GetVoiceConnectorResponseSuccess, _GetVoiceConnectorStreamingConfigurationResponseSuccess, _GetVoiceConnectorTerminationHealthResponseSuccess, _GetVoiceConnectorTerminationResponseSuccess, _GetVoiceProfileDomainResponseSuccess, _GetVoiceProfileResponseSuccess, _GetVoiceToneAnalysisTaskResponseSuccess, _ListAvailableVoiceConnectorRegionsResponseSuccess, _ListPhoneNumberOrdersResponseSuccess, _ListPhoneNumbersResponseSuccess, _ListProxySessionsResponseSuccess, _ListSipMediaApplicationsResponseSuccess, _ListSipRulesResponseSuccess, _ListSupportedPhoneNumberCountriesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVoiceConnectorGroupsResponseSuccess, _ListVoiceConnectorTerminationCredentialsResponseSuccess, _ListVoiceConnectorsResponseSuccess, _ListVoiceProfileDomainsResponseSuccess, _ListVoiceProfilesResponseSuccess, _PutSipMediaApplicationAlexaSkillConfigurationResponseSuccess, _PutSipMediaApplicationLoggingConfigurationResponseSuccess, _PutVoiceConnectorEmergencyCallingConfigurationResponseSuccess, _PutVoiceConnectorExternalSystemsConfigurationResponseSuccess, _PutVoiceConnectorLoggingConfigurationResponseSuccess, _PutVoiceConnectorOriginationResponseSuccess, _PutVoiceConnectorProxyResponseSuccess, _PutVoiceConnectorStreamingConfigurationResponseSuccess, _PutVoiceConnectorTerminationResponseSuccess, _RestorePhoneNumberResponseSuccess, _SearchAvailablePhoneNumbersResponseSuccess, _StartSpeakerSearchTaskResponseSuccess, _StartVoiceToneAnalysisTaskResponseSuccess, _UpdatePhoneNumberResponseSuccess, _UpdateProxySessionResponseSuccess, _UpdateSipMediaApplicationCallResponseSuccess, _UpdateSipMediaApplicationResponseSuccess, _UpdateSipRuleResponseSuccess, _UpdateVoiceConnectorGroupResponseSuccess, _UpdateVoiceConnectorResponseSuccess, _UpdateVoiceProfileDomainResponseSuccess, _UpdateVoiceProfileResponseSuccess, _ValidateE911AddressResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_phone_numbers_with_voice_connector(params = {}) ⇒ Types::AssociatePhoneNumbersWithVoiceConnectorResponse
Associates phone numbers with the specified Amazon Chime SDK Voice Connector.
-
#associate_phone_numbers_with_voice_connector_group(params = {}) ⇒ Types::AssociatePhoneNumbersWithVoiceConnectorGroupResponse
Associates phone numbers with the specified Amazon Chime SDK Voice Connector group.
-
#batch_delete_phone_number(params = {}) ⇒ Types::BatchDeletePhoneNumberResponse
Moves phone numbers into the Deletion queue.
-
#batch_update_phone_number(params = {}) ⇒ Types::BatchUpdatePhoneNumberResponse
Updates phone number product types, calling names, or phone number names.
-
#create_phone_number_order(params = {}) ⇒ Types::CreatePhoneNumberOrderResponse
Creates an order for phone numbers to be provisioned.
-
#create_proxy_session(params = {}) ⇒ Types::CreateProxySessionResponse
Creates a proxy session for the specified Amazon Chime SDK Voice Connector for the specified participant phone numbers.
-
#create_sip_media_application(params = {}) ⇒ Types::CreateSipMediaApplicationResponse
Creates a SIP media application.
-
#create_sip_media_application_call(params = {}) ⇒ Types::CreateSipMediaApplicationCallResponse
Creates an outbound call to a phone number from the phone number specified in the request, and it invokes the endpoint of the specified
sipMediaApplicationId. -
#create_sip_rule(params = {}) ⇒ Types::CreateSipRuleResponse
Creates a SIP rule, which can be used to run a SIP media application as a target for a specific trigger type.
-
#create_voice_connector(params = {}) ⇒ Types::CreateVoiceConnectorResponse
Creates an Amazon Chime SDK Voice Connector.
-
#create_voice_connector_group(params = {}) ⇒ Types::CreateVoiceConnectorGroupResponse
Creates an Amazon Chime SDK Voice Connector group under the administrator's AWS account.
-
#create_voice_profile(params = {}) ⇒ Types::CreateVoiceProfileResponse
Creates a voice profile, which consists of an enrolled user and their latest voice print.
-
#create_voice_profile_domain(params = {}) ⇒ Types::CreateVoiceProfileDomainResponse
Creates a voice profile domain, a collection of voice profiles, their voice prints, and encrypted enrollment audio.
-
#delete_phone_number(params = {}) ⇒ Struct
Moves the specified phone number into the Deletion queue.
-
#delete_proxy_session(params = {}) ⇒ Struct
Deletes the specified proxy session from the specified Amazon Chime SDK Voice Connector.
-
#delete_sip_media_application(params = {}) ⇒ Struct
Deletes a SIP media application.
-
#delete_sip_rule(params = {}) ⇒ Struct
Deletes a SIP rule.
-
#delete_voice_connector(params = {}) ⇒ Struct
Deletes an Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_emergency_calling_configuration(params = {}) ⇒ Struct
Deletes the emergency calling details from the specified Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_external_systems_configuration(params = {}) ⇒ Struct
Deletes the external systems configuration for a Voice Connector.
-
#delete_voice_connector_group(params = {}) ⇒ Struct
Deletes an Amazon Chime SDK Voice Connector group.
-
#delete_voice_connector_origination(params = {}) ⇒ Struct
Deletes the origination settings for the specified Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_proxy(params = {}) ⇒ Struct
Deletes the proxy configuration from the specified Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_streaming_configuration(params = {}) ⇒ Struct
Deletes a Voice Connector's streaming configuration.
-
#delete_voice_connector_termination(params = {}) ⇒ Struct
Deletes the termination settings for the specified Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_termination_credentials(params = {}) ⇒ Struct
Deletes the specified SIP credentials used by your equipment to authenticate during call termination.
-
#delete_voice_profile(params = {}) ⇒ Struct
Deletes a voice profile, including its voice print and enrollment data.
-
#delete_voice_profile_domain(params = {}) ⇒ Struct
Deletes all voice profiles in the domain.
-
#disassociate_phone_numbers_from_voice_connector(params = {}) ⇒ Types::DisassociatePhoneNumbersFromVoiceConnectorResponse
Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector.
-
#disassociate_phone_numbers_from_voice_connector_group(params = {}) ⇒ Types::DisassociatePhoneNumbersFromVoiceConnectorGroupResponse
Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector group.
-
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsResponse
Retrieves the global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
-
#get_phone_number(params = {}) ⇒ Types::GetPhoneNumberResponse
Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.
-
#get_phone_number_order(params = {}) ⇒ Types::GetPhoneNumberOrderResponse
Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.
-
#get_phone_number_settings(params = {}) ⇒ Types::GetPhoneNumberSettingsResponse
Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.
-
#get_proxy_session(params = {}) ⇒ Types::GetProxySessionResponse
Retrieves the specified proxy session details for the specified Amazon Chime SDK Voice Connector.
-
#get_sip_media_application(params = {}) ⇒ Types::GetSipMediaApplicationResponse
Retrieves the information for a SIP media application, including name, AWS Region, and endpoints.
-
#get_sip_media_application_alexa_skill_configuration(params = {}) ⇒ Types::GetSipMediaApplicationAlexaSkillConfigurationResponse
Gets the Alexa Skill configuration for the SIP media application.
-
#get_sip_media_application_logging_configuration(params = {}) ⇒ Types::GetSipMediaApplicationLoggingConfigurationResponse
Retrieves the logging configuration for the specified SIP media application.
-
#get_sip_rule(params = {}) ⇒ Types::GetSipRuleResponse
Retrieves the details of a SIP rule, such as the rule ID, name, triggers, and target endpoints.
-
#get_speaker_search_task(params = {}) ⇒ Types::GetSpeakerSearchTaskResponse
Retrieves the details of the specified speaker search task.
-
#get_voice_connector(params = {}) ⇒ Types::GetVoiceConnectorResponse
Retrieves details for the specified Amazon Chime SDK Voice Connector, such as timestamps,name, outbound host, and encryption requirements.
-
#get_voice_connector_emergency_calling_configuration(params = {}) ⇒ Types::GetVoiceConnectorEmergencyCallingConfigurationResponse
Retrieves the emergency calling configuration details for the specified Voice Connector.
-
#get_voice_connector_external_systems_configuration(params = {}) ⇒ Types::GetVoiceConnectorExternalSystemsConfigurationResponse
Gets information about an external systems configuration for a Voice Connector.
-
#get_voice_connector_group(params = {}) ⇒ Types::GetVoiceConnectorGroupResponse
Retrieves details for the specified Amazon Chime SDK Voice Connector group, such as timestamps,name, and associated
VoiceConnectorItems. -
#get_voice_connector_logging_configuration(params = {}) ⇒ Types::GetVoiceConnectorLoggingConfigurationResponse
Retrieves the logging configuration settings for the specified Voice Connector.
-
#get_voice_connector_origination(params = {}) ⇒ Types::GetVoiceConnectorOriginationResponse
Retrieves the origination settings for the specified Voice Connector.
-
#get_voice_connector_proxy(params = {}) ⇒ Types::GetVoiceConnectorProxyResponse
Retrieves the proxy configuration details for the specified Amazon Chime SDK Voice Connector.
-
#get_voice_connector_streaming_configuration(params = {}) ⇒ Types::GetVoiceConnectorStreamingConfigurationResponse
Retrieves the streaming configuration details for the specified Amazon Chime SDK Voice Connector.
-
#get_voice_connector_termination(params = {}) ⇒ Types::GetVoiceConnectorTerminationResponse
Retrieves the termination setting details for the specified Voice Connector.
-
#get_voice_connector_termination_health(params = {}) ⇒ Types::GetVoiceConnectorTerminationHealthResponse
Retrieves information about the last time a
SIP OPTIONSping was received from your SIP infrastructure for the specified Amazon Chime SDK Voice Connector. -
#get_voice_profile(params = {}) ⇒ Types::GetVoiceProfileResponse
Retrieves the details of the specified voice profile.
-
#get_voice_profile_domain(params = {}) ⇒ Types::GetVoiceProfileDomainResponse
Retrieves the details of the specified voice profile domain.
-
#get_voice_tone_analysis_task(params = {}) ⇒ Types::GetVoiceToneAnalysisTaskResponse
Retrieves the details of a voice tone analysis task.
-
#list_available_voice_connector_regions(params = {}) ⇒ Types::ListAvailableVoiceConnectorRegionsResponse
Lists the available AWS Regions in which you can create an Amazon Chime SDK Voice Connector.
-
#list_phone_number_orders(params = {}) ⇒ Types::ListPhoneNumberOrdersResponse
Lists the phone numbers for an administrator's Amazon Chime SDK account.
-
#list_phone_numbers(params = {}) ⇒ Types::ListPhoneNumbersResponse
Lists the phone numbers for the specified Amazon Chime SDK account, Amazon Chime SDK user, Amazon Chime SDK Voice Connector, or Amazon Chime SDK Voice Connector group.
-
#list_proxy_sessions(params = {}) ⇒ Types::ListProxySessionsResponse
Lists the proxy sessions for the specified Amazon Chime SDK Voice Connector.
-
#list_sip_media_applications(params = {}) ⇒ Types::ListSipMediaApplicationsResponse
Lists the SIP media applications under the administrator's AWS account.
-
#list_sip_rules(params = {}) ⇒ Types::ListSipRulesResponse
Lists the SIP rules under the administrator's AWS account.
-
#list_supported_phone_number_countries(params = {}) ⇒ Types::ListSupportedPhoneNumberCountriesResponse
Lists the countries that you can order phone numbers from.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags in a given resource.
-
#list_voice_connector_groups(params = {}) ⇒ Types::ListVoiceConnectorGroupsResponse
Lists the Amazon Chime SDK Voice Connector groups in the administrator's AWS account.
-
#list_voice_connector_termination_credentials(params = {}) ⇒ Types::ListVoiceConnectorTerminationCredentialsResponse
Lists the SIP credentials for the specified Amazon Chime SDK Voice Connector.
-
#list_voice_connectors(params = {}) ⇒ Types::ListVoiceConnectorsResponse
Lists the Amazon Chime SDK Voice Connectors in the administrators AWS account.
-
#list_voice_profile_domains(params = {}) ⇒ Types::ListVoiceProfileDomainsResponse
Lists the specified voice profile domains in the administrator's AWS account.
-
#list_voice_profiles(params = {}) ⇒ Types::ListVoiceProfilesResponse
Lists the voice profiles in a voice profile domain.
-
#put_sip_media_application_alexa_skill_configuration(params = {}) ⇒ Types::PutSipMediaApplicationAlexaSkillConfigurationResponse
Updates the Alexa Skill configuration for the SIP media application.
-
#put_sip_media_application_logging_configuration(params = {}) ⇒ Types::PutSipMediaApplicationLoggingConfigurationResponse
Updates the logging configuration for the specified SIP media application.
-
#put_voice_connector_emergency_calling_configuration(params = {}) ⇒ Types::PutVoiceConnectorEmergencyCallingConfigurationResponse
Updates a Voice Connector's emergency calling configuration.
-
#put_voice_connector_external_systems_configuration(params = {}) ⇒ Types::PutVoiceConnectorExternalSystemsConfigurationResponse
Adds an external systems configuration to a Voice Connector.
-
#put_voice_connector_logging_configuration(params = {}) ⇒ Types::PutVoiceConnectorLoggingConfigurationResponse
Updates a Voice Connector's logging configuration.
-
#put_voice_connector_origination(params = {}) ⇒ Types::PutVoiceConnectorOriginationResponse
Updates a Voice Connector's origination settings.
-
#put_voice_connector_proxy(params = {}) ⇒ Types::PutVoiceConnectorProxyResponse
Puts the specified proxy configuration to the specified Amazon Chime SDK Voice Connector.
-
#put_voice_connector_streaming_configuration(params = {}) ⇒ Types::PutVoiceConnectorStreamingConfigurationResponse
Updates a Voice Connector's streaming configuration settings.
-
#put_voice_connector_termination(params = {}) ⇒ Types::PutVoiceConnectorTerminationResponse
Updates a Voice Connector's termination settings.
-
#put_voice_connector_termination_credentials(params = {}) ⇒ Struct
Updates a Voice Connector's termination credentials.
-
#restore_phone_number(params = {}) ⇒ Types::RestorePhoneNumberResponse
Restores a deleted phone number.
-
#search_available_phone_numbers(params = {}) ⇒ Types::SearchAvailablePhoneNumbersResponse
Searches the provisioned phone numbers in an organization.
-
#start_speaker_search_task(params = {}) ⇒ Types::StartSpeakerSearchTaskResponse
Starts a speaker search task.
-
#start_voice_tone_analysis_task(params = {}) ⇒ Types::StartVoiceToneAnalysisTaskResponse
Starts a voice tone analysis task.
-
#stop_speaker_search_task(params = {}) ⇒ Struct
Stops a speaker search task.
-
#stop_voice_tone_analysis_task(params = {}) ⇒ Struct
Stops a voice tone analysis task.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_global_settings(params = {}) ⇒ Struct
Updates global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
-
#update_phone_number(params = {}) ⇒ Types::UpdatePhoneNumberResponse
Updates phone number details, such as product type, calling name, or phone number name for the specified phone number ID.
-
#update_phone_number_settings(params = {}) ⇒ Struct
Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name.
-
#update_proxy_session(params = {}) ⇒ Types::UpdateProxySessionResponse
Updates the specified proxy session details, such as voice or SMS capabilities.
-
#update_sip_media_application(params = {}) ⇒ Types::UpdateSipMediaApplicationResponse
Updates the details of the specified SIP media application.
-
#update_sip_media_application_call(params = {}) ⇒ Types::UpdateSipMediaApplicationCallResponse
Invokes the AWS Lambda function associated with the SIP media application and transaction ID in an update request.
-
#update_sip_rule(params = {}) ⇒ Types::UpdateSipRuleResponse
Updates the details of the specified SIP rule.
-
#update_voice_connector(params = {}) ⇒ Types::UpdateVoiceConnectorResponse
Updates the details for the specified Amazon Chime SDK Voice Connector.
-
#update_voice_connector_group(params = {}) ⇒ Types::UpdateVoiceConnectorGroupResponse
Updates the settings for the specified Amazon Chime SDK Voice Connector group.
-
#update_voice_profile(params = {}) ⇒ Types::UpdateVoiceProfileResponse
Updates the specified voice profile’s voice print and refreshes its expiration timestamp.
-
#update_voice_profile_domain(params = {}) ⇒ Types::UpdateVoiceProfileDomainResponse
Updates the settings for the specified voice profile domain.
-
#validate_e911_address(params = {}) ⇒ Types::ValidateE911AddressResponse
Validates an address to be used for 911 calls made with Amazon Chime SDK Voice Connectors.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4507 4508 4509 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 4507 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4510 4511 4512 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 4510 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_phone_numbers_with_voice_connector(params = {}) ⇒ Types::AssociatePhoneNumbersWithVoiceConnectorResponse
Associates phone numbers with the specified Amazon Chime SDK Voice Connector.
86 |
# File 'sig/client.rbs', line 86
def associate_phone_numbers_with_voice_connector: (
|
#associate_phone_numbers_with_voice_connector_group(params = {}) ⇒ Types::AssociatePhoneNumbersWithVoiceConnectorGroupResponse
Associates phone numbers with the specified Amazon Chime SDK Voice Connector group.
98 |
# File 'sig/client.rbs', line 98
def associate_phone_numbers_with_voice_connector_group: (
|
#batch_delete_phone_number(params = {}) ⇒ Types::BatchDeletePhoneNumberResponse
Moves phone numbers into the Deletion queue. Phone numbers must be disassociated from any users or Amazon Chime SDK Voice Connectors before they can be deleted.
Phone numbers remain in the Deletion queue for 7 days before they are deleted permanently.
110 |
# File 'sig/client.rbs', line 110
def batch_delete_phone_number: (
|
#batch_update_phone_number(params = {}) ⇒ Types::BatchUpdatePhoneNumberResponse
Updates phone number product types, calling names, or phone number
names. You can update one attribute at a time for each
UpdatePhoneNumberRequestItem. For example, you can update the
product type, the calling name, or phone name.
phoneNumberId in a request.
120 |
# File 'sig/client.rbs', line 120
def batch_update_phone_number: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 4480 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ChimeSDKVoice') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chimesdkvoice' context[:gem_version] = '1.62.0' Seahorse::Client::Request.new(handlers, context) end |
#create_phone_number_order(params = {}) ⇒ Types::CreatePhoneNumberOrderResponse
Creates an order for phone numbers to be provisioned. For numbers outside the U.S., you must use the Amazon Chime SDK SIP media application dial-in product type.
137 |
# File 'sig/client.rbs', line 137
def create_phone_number_order: (
|
#create_proxy_session(params = {}) ⇒ Types::CreateProxySessionResponse
Creates a proxy session for the specified Amazon Chime SDK Voice Connector for the specified participant phone numbers.
End of support notice: On April 7, 2026, AWS will end support for Amazon Chime SDK proxy sessions.
149 |
# File 'sig/client.rbs', line 149
def create_proxy_session: (
|
#create_sip_media_application(params = {}) ⇒ Types::CreateSipMediaApplicationResponse
Creates a SIP media application. For more information about SIP media applications, see Managing SIP media applications and rules in the Amazon Chime SDK Administrator Guide.
169 |
# File 'sig/client.rbs', line 169
def create_sip_media_application: (
|
#create_sip_media_application_call(params = {}) ⇒ Types::CreateSipMediaApplicationCallResponse
Creates an outbound call to a phone number from the phone number
specified in the request, and it invokes the endpoint of the specified
sipMediaApplicationId.
191 |
# File 'sig/client.rbs', line 191
def create_sip_media_application_call: (
|
#create_sip_rule(params = {}) ⇒ Types::CreateSipRuleResponse
Creates a SIP rule, which can be used to run a SIP media application as a target for a specific trigger type. For more information about SIP rules, see Managing SIP media applications and rules in the Amazon Chime SDK Administrator Guide.
205 |
# File 'sig/client.rbs', line 205
def create_sip_rule: (
|
#create_voice_connector(params = {}) ⇒ Types::CreateVoiceConnectorResponse
Creates an Amazon Chime SDK Voice Connector. For more information about Voice Connectors, see Managing Amazon Chime SDK Voice Connector groups in the Amazon Chime SDK Administrator Guide.
225 |
# File 'sig/client.rbs', line 225
def create_voice_connector: (
|
#create_voice_connector_group(params = {}) ⇒ Types::CreateVoiceConnectorGroupResponse
Creates an Amazon Chime SDK Voice Connector group under the
administrator's AWS account. You can associate Amazon Chime SDK Voice
Connectors with the Voice Connector group by including
VoiceConnectorItems in the request.
You can include Voice Connectors from different AWS Regions in your group. This creates a fault tolerant mechanism for fallback in case of availability events.
245 |
# File 'sig/client.rbs', line 245
def create_voice_connector_group: (
|
#create_voice_profile(params = {}) ⇒ Types::CreateVoiceProfileResponse
Creates a voice profile, which consists of an enrolled user and their latest voice print.
Before creating any voice profiles, you must provide all notices and obtain all consents from the speaker as required under applicable privacy and biometrics laws, and as required under the AWS service terms for the Amazon Chime SDK.
For more information about voice profiles and voice analytics, see Using Amazon Chime SDK Voice Analytics in the Amazon Chime SDK Developer Guide.
262 |
# File 'sig/client.rbs', line 262
def create_voice_profile: (
|
#create_voice_profile_domain(params = {}) ⇒ Types::CreateVoiceProfileDomainResponse
Creates a voice profile domain, a collection of voice profiles, their voice prints, and encrypted enrollment audio.
Before creating any voice profiles, you must provide all notices and obtain all consents from the speaker as required under applicable privacy and biometrics laws, and as required under the AWS service terms for the Amazon Chime SDK.
For more information about voice profile domains, see Using Amazon Chime SDK Voice Analytics in the Amazon Chime SDK Developer Guide.
272 |
# File 'sig/client.rbs', line 272
def create_voice_profile_domain: (
|
#delete_phone_number(params = {}) ⇒ Struct
Moves the specified phone number into the Deletion queue. A phone number must be disassociated from any users or Amazon Chime SDK Voice Connectors before it can be deleted.
Deleted phone numbers remain in the Deletion queue queue for 7 days before they are deleted permanently.
289 |
# File 'sig/client.rbs', line 289
def delete_phone_number: (
|
#delete_proxy_session(params = {}) ⇒ Struct
Deletes the specified proxy session from the specified Amazon Chime SDK Voice Connector.
End of support notice: On April 7, 2026, AWS will end support for Amazon Chime SDK proxy sessions.
295 |
# File 'sig/client.rbs', line 295
def delete_proxy_session: (
|
#delete_sip_media_application(params = {}) ⇒ Struct
Deletes a SIP media application.
302 |
# File 'sig/client.rbs', line 302
def delete_sip_media_application: (
|
#delete_sip_rule(params = {}) ⇒ Struct
Deletes a SIP rule.
308 |
# File 'sig/client.rbs', line 308
def delete_sip_rule: (
|
#delete_voice_connector(params = {}) ⇒ Struct
Deletes an Amazon Chime SDK Voice Connector. Any phone numbers associated with the Amazon Chime SDK Voice Connector must be disassociated from it before it can be deleted.
314 |
# File 'sig/client.rbs', line 314
def delete_voice_connector: (
|
#delete_voice_connector_emergency_calling_configuration(params = {}) ⇒ Struct
Deletes the emergency calling details from the specified Amazon Chime SDK Voice Connector.
320 |
# File 'sig/client.rbs', line 320
def delete_voice_connector_emergency_calling_configuration: (
|
#delete_voice_connector_external_systems_configuration(params = {}) ⇒ Struct
Deletes the external systems configuration for a Voice Connector.
326 |
# File 'sig/client.rbs', line 326
def delete_voice_connector_external_systems_configuration: (
|
#delete_voice_connector_group(params = {}) ⇒ Struct
Deletes an Amazon Chime SDK Voice Connector group. Any
VoiceConnectorItems and phone numbers associated with the group must
be removed before it can be deleted.
332 |
# File 'sig/client.rbs', line 332
def delete_voice_connector_group: (
|
#delete_voice_connector_origination(params = {}) ⇒ Struct
Deletes the origination settings for the specified Amazon Chime SDK Voice Connector.
338 |
# File 'sig/client.rbs', line 338
def delete_voice_connector_origination: (
|
#delete_voice_connector_proxy(params = {}) ⇒ Struct
Deletes the proxy configuration from the specified Amazon Chime SDK Voice Connector.
End of support notice: On April 7, 2026, AWS will end support for Amazon Chime SDK proxy sessions.
344 |
# File 'sig/client.rbs', line 344
def delete_voice_connector_proxy: (
|
#delete_voice_connector_streaming_configuration(params = {}) ⇒ Struct
Deletes a Voice Connector's streaming configuration.
350 |
# File 'sig/client.rbs', line 350
def delete_voice_connector_streaming_configuration: (
|
#delete_voice_connector_termination(params = {}) ⇒ Struct
Deletes the termination settings for the specified Amazon Chime SDK Voice Connector.
356 |
# File 'sig/client.rbs', line 356
def delete_voice_connector_termination: (
|
#delete_voice_connector_termination_credentials(params = {}) ⇒ Struct
Deletes the specified SIP credentials used by your equipment to authenticate during call termination.
362 |
# File 'sig/client.rbs', line 362
def delete_voice_connector_termination_credentials: (
|
#delete_voice_profile(params = {}) ⇒ Struct
Deletes a voice profile, including its voice print and enrollment data. WARNING: This action is not reversible.
369 |
# File 'sig/client.rbs', line 369
def delete_voice_profile: (
|
#delete_voice_profile_domain(params = {}) ⇒ Struct
Deletes all voice profiles in the domain. WARNING: This action is not reversible.
375 |
# File 'sig/client.rbs', line 375
def delete_voice_profile_domain: (
|
#disassociate_phone_numbers_from_voice_connector(params = {}) ⇒ Types::DisassociatePhoneNumbersFromVoiceConnectorResponse
Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector.
385 |
# File 'sig/client.rbs', line 385
def disassociate_phone_numbers_from_voice_connector: (
|
#disassociate_phone_numbers_from_voice_connector_group(params = {}) ⇒ Types::DisassociatePhoneNumbersFromVoiceConnectorGroupResponse
Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector group.
396 |
# File 'sig/client.rbs', line 396
def disassociate_phone_numbers_from_voice_connector_group: (
|
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsResponse
Retrieves the global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
407 408 |
# File 'sig/client.rbs', line 407
def get_global_settings: () -> _GetGlobalSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetGlobalSettingsResponseSuccess
|
#get_phone_number(params = {}) ⇒ Types::GetPhoneNumberResponse
Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.
415 |
# File 'sig/client.rbs', line 415
def get_phone_number: (
|
#get_phone_number_order(params = {}) ⇒ Types::GetPhoneNumberOrderResponse
Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.
425 |
# File 'sig/client.rbs', line 425
def get_phone_number_order: (
|
#get_phone_number_settings(params = {}) ⇒ Types::GetPhoneNumberSettingsResponse
Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.
436 437 |
# File 'sig/client.rbs', line 436
def get_phone_number_settings: () -> _GetPhoneNumberSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetPhoneNumberSettingsResponseSuccess
|
#get_proxy_session(params = {}) ⇒ Types::GetProxySessionResponse
Retrieves the specified proxy session details for the specified Amazon Chime SDK Voice Connector.
End of support notice: On April 7, 2026, AWS will end support for Amazon Chime SDK proxy sessions.
444 |
# File 'sig/client.rbs', line 444
def get_proxy_session: (
|
#get_sip_media_application(params = {}) ⇒ Types::GetSipMediaApplicationResponse
Retrieves the information for a SIP media application, including name, AWS Region, and endpoints.
455 |
# File 'sig/client.rbs', line 455
def get_sip_media_application: (
|
#get_sip_media_application_alexa_skill_configuration(params = {}) ⇒ Types::GetSipMediaApplicationAlexaSkillConfigurationResponse
Gets the Alexa Skill configuration for the SIP media application.
Due to changes made by the Amazon Alexa service, this API is no longer available for use. For more information, refer to the Alexa Smart Properties page.
465 |
# File 'sig/client.rbs', line 465
def get_sip_media_application_alexa_skill_configuration: (
|
#get_sip_media_application_logging_configuration(params = {}) ⇒ Types::GetSipMediaApplicationLoggingConfigurationResponse
Retrieves the logging configuration for the specified SIP media application.
475 |
# File 'sig/client.rbs', line 475
def get_sip_media_application_logging_configuration: (
|
#get_sip_rule(params = {}) ⇒ Types::GetSipRuleResponse
Retrieves the details of a SIP rule, such as the rule ID, name, triggers, and target endpoints.
485 |
# File 'sig/client.rbs', line 485
def get_sip_rule: (
|
#get_speaker_search_task(params = {}) ⇒ Types::GetSpeakerSearchTaskResponse
Retrieves the details of the specified speaker search task.
495 |
# File 'sig/client.rbs', line 495
def get_speaker_search_task: (
|
#get_voice_connector(params = {}) ⇒ Types::GetVoiceConnectorResponse
Retrieves details for the specified Amazon Chime SDK Voice Connector, such as timestamps,name, outbound host, and encryption requirements.
506 |
# File 'sig/client.rbs', line 506
def get_voice_connector: (
|
#get_voice_connector_emergency_calling_configuration(params = {}) ⇒ Types::GetVoiceConnectorEmergencyCallingConfigurationResponse
Retrieves the emergency calling configuration details for the specified Voice Connector.
516 |
# File 'sig/client.rbs', line 516
def get_voice_connector_emergency_calling_configuration: (
|
#get_voice_connector_external_systems_configuration(params = {}) ⇒ Types::GetVoiceConnectorExternalSystemsConfigurationResponse
Gets information about an external systems configuration for a Voice Connector.
526 |
# File 'sig/client.rbs', line 526
def get_voice_connector_external_systems_configuration: (
|
#get_voice_connector_group(params = {}) ⇒ Types::GetVoiceConnectorGroupResponse
Retrieves details for the specified Amazon Chime SDK Voice Connector
group, such as timestamps,name, and associated VoiceConnectorItems.
536 |
# File 'sig/client.rbs', line 536
def get_voice_connector_group: (
|
#get_voice_connector_logging_configuration(params = {}) ⇒ Types::GetVoiceConnectorLoggingConfigurationResponse
Retrieves the logging configuration settings for the specified Voice Connector. Shows whether SIP message logs are enabled for sending to Amazon CloudWatch Logs.
546 |
# File 'sig/client.rbs', line 546
def get_voice_connector_logging_configuration: (
|
#get_voice_connector_origination(params = {}) ⇒ Types::GetVoiceConnectorOriginationResponse
Retrieves the origination settings for the specified Voice Connector.
556 |
# File 'sig/client.rbs', line 556
def get_voice_connector_origination: (
|
#get_voice_connector_proxy(params = {}) ⇒ Types::GetVoiceConnectorProxyResponse
Retrieves the proxy configuration details for the specified Amazon Chime SDK Voice Connector.
End of support notice: On April 7, 2026, AWS will end support for Amazon Chime SDK proxy sessions.
566 |
# File 'sig/client.rbs', line 566
def get_voice_connector_proxy: (
|
#get_voice_connector_streaming_configuration(params = {}) ⇒ Types::GetVoiceConnectorStreamingConfigurationResponse
Retrieves the streaming configuration details for the specified Amazon Chime SDK Voice Connector. Shows whether media streaming is enabled for sending to Amazon Kinesis. It also shows the retention period, in hours, for the Amazon Kinesis data.
576 |
# File 'sig/client.rbs', line 576
def get_voice_connector_streaming_configuration: (
|
#get_voice_connector_termination(params = {}) ⇒ Types::GetVoiceConnectorTerminationResponse
Retrieves the termination setting details for the specified Voice Connector.
586 |
# File 'sig/client.rbs', line 586
def get_voice_connector_termination: (
|
#get_voice_connector_termination_health(params = {}) ⇒ Types::GetVoiceConnectorTerminationHealthResponse
Retrieves information about the last time a SIP OPTIONS ping was
received from your SIP infrastructure for the specified Amazon Chime
SDK Voice Connector.
596 |
# File 'sig/client.rbs', line 596
def get_voice_connector_termination_health: (
|
#get_voice_profile(params = {}) ⇒ Types::GetVoiceProfileResponse
Retrieves the details of the specified voice profile.
606 |
# File 'sig/client.rbs', line 606
def get_voice_profile: (
|
#get_voice_profile_domain(params = {}) ⇒ Types::GetVoiceProfileDomainResponse
Retrieves the details of the specified voice profile domain.
616 |
# File 'sig/client.rbs', line 616
def get_voice_profile_domain: (
|
#get_voice_tone_analysis_task(params = {}) ⇒ Types::GetVoiceToneAnalysisTaskResponse
Retrieves the details of a voice tone analysis task.
626 |
# File 'sig/client.rbs', line 626
def get_voice_tone_analysis_task: (
|
#list_available_voice_connector_regions(params = {}) ⇒ Types::ListAvailableVoiceConnectorRegionsResponse
Lists the available AWS Regions in which you can create an Amazon Chime SDK Voice Connector.
638 639 |
# File 'sig/client.rbs', line 638
def list_available_voice_connector_regions: () -> _ListAvailableVoiceConnectorRegionsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _ListAvailableVoiceConnectorRegionsResponseSuccess
|
#list_phone_number_orders(params = {}) ⇒ Types::ListPhoneNumberOrdersResponse
Lists the phone numbers for an administrator's Amazon Chime SDK account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
647 |
# File 'sig/client.rbs', line 647
def list_phone_number_orders: (
|
#list_phone_numbers(params = {}) ⇒ Types::ListPhoneNumbersResponse
Lists the phone numbers for the specified Amazon Chime SDK account, Amazon Chime SDK user, Amazon Chime SDK Voice Connector, or Amazon Chime SDK Voice Connector group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
659 |
# File 'sig/client.rbs', line 659
def list_phone_numbers: (
|
#list_proxy_sessions(params = {}) ⇒ Types::ListProxySessionsResponse
Lists the proxy sessions for the specified Amazon Chime SDK Voice Connector.
End of support notice: On April 7, 2026, AWS will end support for Amazon Chime SDK proxy sessions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
675 |
# File 'sig/client.rbs', line 675
def list_proxy_sessions: (
|
#list_sip_media_applications(params = {}) ⇒ Types::ListSipMediaApplicationsResponse
Lists the SIP media applications under the administrator's AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
689 |
# File 'sig/client.rbs', line 689
def list_sip_media_applications: (
|
#list_sip_rules(params = {}) ⇒ Types::ListSipRulesResponse
Lists the SIP rules under the administrator's AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
701 |
# File 'sig/client.rbs', line 701
def list_sip_rules: (
|
#list_supported_phone_number_countries(params = {}) ⇒ Types::ListSupportedPhoneNumberCountriesResponse
Lists the countries that you can order phone numbers from.
713 |
# File 'sig/client.rbs', line 713
def list_supported_phone_number_countries: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags in a given resource.
723 |
# File 'sig/client.rbs', line 723
def list_tags_for_resource: (
|
#list_voice_connector_groups(params = {}) ⇒ Types::ListVoiceConnectorGroupsResponse
Lists the Amazon Chime SDK Voice Connector groups in the administrator's AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
734 |
# File 'sig/client.rbs', line 734
def list_voice_connector_groups: (
|
#list_voice_connector_termination_credentials(params = {}) ⇒ Types::ListVoiceConnectorTerminationCredentialsResponse
Lists the SIP credentials for the specified Amazon Chime SDK Voice Connector.
745 |
# File 'sig/client.rbs', line 745
def list_voice_connector_termination_credentials: (
|
#list_voice_connectors(params = {}) ⇒ Types::ListVoiceConnectorsResponse
Lists the Amazon Chime SDK Voice Connectors in the administrators AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
756 |
# File 'sig/client.rbs', line 756
def list_voice_connectors: (
|
#list_voice_profile_domains(params = {}) ⇒ Types::ListVoiceProfileDomainsResponse
Lists the specified voice profile domains in the administrator's AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
768 |
# File 'sig/client.rbs', line 768
def list_voice_profile_domains: (
|
#list_voice_profiles(params = {}) ⇒ Types::ListVoiceProfilesResponse
Lists the voice profiles in a voice profile domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
780 |
# File 'sig/client.rbs', line 780
def list_voice_profiles: (
|
#put_sip_media_application_alexa_skill_configuration(params = {}) ⇒ Types::PutSipMediaApplicationAlexaSkillConfigurationResponse
Updates the Alexa Skill configuration for the SIP media application.
Due to changes made by the Amazon Alexa service, this API is no longer available for use. For more information, refer to the Alexa Smart Properties page.
792 |
# File 'sig/client.rbs', line 792
def put_sip_media_application_alexa_skill_configuration: (
|
#put_sip_media_application_logging_configuration(params = {}) ⇒ Types::PutSipMediaApplicationLoggingConfigurationResponse
Updates the logging configuration for the specified SIP media application.
806 |
# File 'sig/client.rbs', line 806
def put_sip_media_application_logging_configuration: (
|
#put_voice_connector_emergency_calling_configuration(params = {}) ⇒ Types::PutVoiceConnectorEmergencyCallingConfigurationResponse
Updates a Voice Connector's emergency calling configuration.
819 |
# File 'sig/client.rbs', line 819
def put_voice_connector_emergency_calling_configuration: (
|
#put_voice_connector_external_systems_configuration(params = {}) ⇒ Types::PutVoiceConnectorExternalSystemsConfigurationResponse
Adds an external systems configuration to a Voice Connector.
838 |
# File 'sig/client.rbs', line 838
def put_voice_connector_external_systems_configuration: (
|
#put_voice_connector_logging_configuration(params = {}) ⇒ Types::PutVoiceConnectorLoggingConfigurationResponse
Updates a Voice Connector's logging configuration.
850 |
# File 'sig/client.rbs', line 850
def put_voice_connector_logging_configuration: (
|
#put_voice_connector_origination(params = {}) ⇒ Types::PutVoiceConnectorOriginationResponse
Updates a Voice Connector's origination settings.
864 |
# File 'sig/client.rbs', line 864
def put_voice_connector_origination: (
|
#put_voice_connector_proxy(params = {}) ⇒ Types::PutVoiceConnectorProxyResponse
Puts the specified proxy configuration to the specified Amazon Chime SDK Voice Connector.
End of support notice: On April 7, 2026, AWS will end support for Amazon Chime SDK proxy sessions.
886 |
# File 'sig/client.rbs', line 886
def put_voice_connector_proxy: (
|
#put_voice_connector_streaming_configuration(params = {}) ⇒ Types::PutVoiceConnectorStreamingConfigurationResponse
Updates a Voice Connector's streaming configuration settings.
900 |
# File 'sig/client.rbs', line 900
def put_voice_connector_streaming_configuration: (
|
#put_voice_connector_termination(params = {}) ⇒ Types::PutVoiceConnectorTerminationResponse
Updates a Voice Connector's termination settings.
923 |
# File 'sig/client.rbs', line 923
def put_voice_connector_termination: (
|
#put_voice_connector_termination_credentials(params = {}) ⇒ Struct
Updates a Voice Connector's termination credentials.
936 |
# File 'sig/client.rbs', line 936
def put_voice_connector_termination_credentials: (
|
#restore_phone_number(params = {}) ⇒ Types::RestorePhoneNumberResponse
Restores a deleted phone number.
952 |
# File 'sig/client.rbs', line 952
def restore_phone_number: (
|
#search_available_phone_numbers(params = {}) ⇒ Types::SearchAvailablePhoneNumbersResponse
Searches the provisioned phone numbers in an organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
963 |
# File 'sig/client.rbs', line 963
def search_available_phone_numbers: (
|
#start_speaker_search_task(params = {}) ⇒ Types::StartSpeakerSearchTaskResponse
Starts a speaker search task.
Before starting any speaker search tasks, you must provide all notices and obtain all consents from the speaker as required under applicable privacy and biometrics laws, and as required under the AWS service terms for the Amazon Chime SDK.
980 |
# File 'sig/client.rbs', line 980
def start_speaker_search_task: (
|
#start_voice_tone_analysis_task(params = {}) ⇒ Types::StartVoiceToneAnalysisTaskResponse
Starts a voice tone analysis task. For more information about voice tone analysis, see Using Amazon Chime SDK voice analytics in the Amazon Chime SDK Developer Guide.
Before starting any voice tone analysis tasks, you must provide all notices and obtain all consents from the speaker as required under applicable privacy and biometrics laws, and as required under the AWS service terms for the Amazon Chime SDK.
994 |
# File 'sig/client.rbs', line 994
def start_voice_tone_analysis_task: (
|
#stop_speaker_search_task(params = {}) ⇒ Struct
Stops a speaker search task.
1003 |
# File 'sig/client.rbs', line 1003
def stop_speaker_search_task: (
|
#stop_voice_tone_analysis_task(params = {}) ⇒ Struct
Stops a voice tone analysis task.
1010 |
# File 'sig/client.rbs', line 1010
def stop_voice_tone_analysis_task: (
|
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
1017 |
# File 'sig/client.rbs', line 1017
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
1029 |
# File 'sig/client.rbs', line 1029
def untag_resource: (
|
#update_global_settings(params = {}) ⇒ Struct
Updates global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
1036 |
# File 'sig/client.rbs', line 1036
def update_global_settings: (
|
#update_phone_number(params = {}) ⇒ Types::UpdatePhoneNumberResponse
Updates phone number details, such as product type, calling name, or phone number name for the specified phone number ID. You can update one phone number detail at a time. For example, you can update either the product type, calling name, or phone number name in one action.
For numbers outside the U.S., you must use the Amazon Chime SDK SIP Media Application Dial-In product type.
Updates to outbound calling names can take 72 hours to complete. Pending updates to outbound calling names must be complete before you can request another update.
1048 |
# File 'sig/client.rbs', line 1048
def update_phone_number: (
|
#update_phone_number_settings(params = {}) ⇒ Struct
Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name. You can update the default outbound calling name once every seven days. Outbound calling names can take up to 72 hours to update.
1057 |
# File 'sig/client.rbs', line 1057
def update_phone_number_settings: (
|
#update_proxy_session(params = {}) ⇒ Types::UpdateProxySessionResponse
Updates the specified proxy session details, such as voice or SMS capabilities.
End of support notice: On April 7, 2026, AWS will end support for Amazon Chime SDK proxy sessions.
1067 |
# File 'sig/client.rbs', line 1067
def update_proxy_session: (
|
#update_sip_media_application(params = {}) ⇒ Types::UpdateSipMediaApplicationResponse
Updates the details of the specified SIP media application.
1080 |
# File 'sig/client.rbs', line 1080
def update_sip_media_application: (
|
#update_sip_media_application_call(params = {}) ⇒ Types::UpdateSipMediaApplicationCallResponse
Invokes the AWS Lambda function associated with the SIP media application and transaction ID in an update request. The Lambda function can then return a new set of actions.
1096 |
# File 'sig/client.rbs', line 1096
def update_sip_media_application_call: (
|
#update_sip_rule(params = {}) ⇒ Types::UpdateSipRuleResponse
Updates the details of the specified SIP rule.
1108 |
# File 'sig/client.rbs', line 1108
def update_sip_rule: (
|
#update_voice_connector(params = {}) ⇒ Types::UpdateVoiceConnectorResponse
Updates the details for the specified Amazon Chime SDK Voice Connector.
1127 |
# File 'sig/client.rbs', line 1127
def update_voice_connector: (
|
#update_voice_connector_group(params = {}) ⇒ Types::UpdateVoiceConnectorGroupResponse
Updates the settings for the specified Amazon Chime SDK Voice Connector group.
1139 |
# File 'sig/client.rbs', line 1139
def update_voice_connector_group: (
|
#update_voice_profile(params = {}) ⇒ Types::UpdateVoiceProfileResponse
Updates the specified voice profile’s voice print and refreshes its expiration timestamp.
As a condition of using this feature, you acknowledge that the collection, use, storage, and retention of your caller’s biometric identifiers and biometric information (“biometric data”) in the form of a digital voiceprint requires the caller’s informed consent via a written release. Such consent is required under various state laws, including biometrics laws in Illinois, Texas, Washington and other state privacy laws.
You must provide a written release to each caller through a process that clearly reflects each caller’s informed consent before using Amazon Chime SDK Voice Insights service, as required under the terms of your agreement with AWS governing your use of the service.
1157 |
# File 'sig/client.rbs', line 1157
def update_voice_profile: (
|
#update_voice_profile_domain(params = {}) ⇒ Types::UpdateVoiceProfileDomainResponse
Updates the settings for the specified voice profile domain.
1168 |
# File 'sig/client.rbs', line 1168
def update_voice_profile_domain: (
|
#validate_e911_address(params = {}) ⇒ Types::ValidateE911AddressResponse
Validates an address to be used for 911 calls made with Amazon Chime SDK Voice Connectors. You can use validated addresses in a Presence Information Data Format Location Object file that you include in SIP requests. That helps ensure that addresses are routed to the appropriate Public Safety Answering Point.
1183 |
# File 'sig/client.rbs', line 1183
def validate_e911_address: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4500 4501 4502 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 4500 def waiter_names [] end |