Class: Aws::ChimeSDKVoice::Types::CreateVoiceConnectorGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ChimeSDKVoice::Types::CreateVoiceConnectorGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chimesdkvoice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #call_distribution_type ⇒ String
-
#name ⇒ String
The name of the Voice Connector group.
-
#voice_connector_items ⇒ Array<Types::VoiceConnectorItem>
Lists the Voice Connectors that inbound calls are routed to.
Instance Attribute Details
#call_distribution_type ⇒ String
536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-chimesdkvoice/types.rb', line 536 class CreateVoiceConnectorGroupRequest < Struct.new( :name, :voice_connector_items, :call_distribution_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Voice Connector group.
536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-chimesdkvoice/types.rb', line 536 class CreateVoiceConnectorGroupRequest < Struct.new( :name, :voice_connector_items, :call_distribution_type) SENSITIVE = [] include Aws::Structure end |
#voice_connector_items ⇒ Array<Types::VoiceConnectorItem>
Lists the Voice Connectors that inbound calls are routed to.
536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-chimesdkvoice/types.rb', line 536 class CreateVoiceConnectorGroupRequest < Struct.new( :name, :voice_connector_items, :call_distribution_type) SENSITIVE = [] include Aws::Structure end |