Class: Aws::ChimeSDKVoice::Types::ListProxySessionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ChimeSDKVoice::Types::ListProxySessionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chimesdkvoice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token used to retrieve the next page of results.
-
#proxy_sessions ⇒ Array<Types::ProxySession>
The proxy sessions' details.
Instance Attribute Details
#next_token ⇒ String
The token used to retrieve the next page of results.
1775 1776 1777 1778 1779 1780 |
# File 'lib/aws-sdk-chimesdkvoice/types.rb', line 1775 class ListProxySessionsResponse < Struct.new( :proxy_sessions, :next_token) SENSITIVE = [] include Aws::Structure end |
#proxy_sessions ⇒ Array<Types::ProxySession>
The proxy sessions' details.
1775 1776 1777 1778 1779 1780 |
# File 'lib/aws-sdk-chimesdkvoice/types.rb', line 1775 class ListProxySessionsResponse < Struct.new( :proxy_sessions, :next_token) SENSITIVE = [] include Aws::Structure end |