Class: Aws::ChimeSDKVoice::Types::ListVoiceProfileDomainsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-chimesdkvoice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in a single call.



2007
2008
2009
2010
2011
2012
# File 'lib/aws-sdk-chimesdkvoice/types.rb', line 2007

class ListVoiceProfileDomainsRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token used to return the next page of results.



2007
2008
2009
2010
2011
2012
# File 'lib/aws-sdk-chimesdkvoice/types.rb', line 2007

class ListVoiceProfileDomainsRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end