Class: Aws::ChimeSDKVoice::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ChimeSDKVoice::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chimesdkvoice/client.rb,
sig/client.rbs
Overview
An API client for ChimeSDKVoice. To construct a client, you need to configure a :region and :credentials.
client = Aws::ChimeSDKVoice::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociatePhoneNumbersWithVoiceConnectorGroupResponseSuccess, _AssociatePhoneNumbersWithVoiceConnectorResponseSuccess, _BatchDeletePhoneNumberResponseSuccess, _BatchUpdatePhoneNumberResponseSuccess, _CreatePhoneNumberOrderResponseSuccess, _CreateProxySessionResponseSuccess, _CreateSipMediaApplicationCallResponseSuccess, _CreateSipMediaApplicationResponseSuccess, _CreateSipRuleResponseSuccess, _CreateVoiceConnectorGroupResponseSuccess, _CreateVoiceConnectorResponseSuccess, _CreateVoiceProfileDomainResponseSuccess, _CreateVoiceProfileResponseSuccess, _DisassociatePhoneNumbersFromVoiceConnectorGroupResponseSuccess, _DisassociatePhoneNumbersFromVoiceConnectorResponseSuccess, _GetGlobalSettingsResponseSuccess, _GetPhoneNumberOrderResponseSuccess, _GetPhoneNumberResponseSuccess, _GetPhoneNumberSettingsResponseSuccess, _GetProxySessionResponseSuccess, _GetSipMediaApplicationAlexaSkillConfigurationResponseSuccess, _GetSipMediaApplicationLoggingConfigurationResponseSuccess, _GetSipMediaApplicationResponseSuccess, _GetSipRuleResponseSuccess, _GetSpeakerSearchTaskResponseSuccess, _GetVoiceConnectorEmergencyCallingConfigurationResponseSuccess, _GetVoiceConnectorExternalSystemsConfigurationResponseSuccess, _GetVoiceConnectorGroupResponseSuccess, _GetVoiceConnectorLoggingConfigurationResponseSuccess, _GetVoiceConnectorOriginationResponseSuccess, _GetVoiceConnectorProxyResponseSuccess, _GetVoiceConnectorResponseSuccess, _GetVoiceConnectorStreamingConfigurationResponseSuccess, _GetVoiceConnectorTerminationHealthResponseSuccess, _GetVoiceConnectorTerminationResponseSuccess, _GetVoiceProfileDomainResponseSuccess, _GetVoiceProfileResponseSuccess, _GetVoiceToneAnalysisTaskResponseSuccess, _ListAvailableVoiceConnectorRegionsResponseSuccess, _ListPhoneNumberOrdersResponseSuccess, _ListPhoneNumbersResponseSuccess, _ListProxySessionsResponseSuccess, _ListSipMediaApplicationsResponseSuccess, _ListSipRulesResponseSuccess, _ListSupportedPhoneNumberCountriesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVoiceConnectorGroupsResponseSuccess, _ListVoiceConnectorTerminationCredentialsResponseSuccess, _ListVoiceConnectorsResponseSuccess, _ListVoiceProfileDomainsResponseSuccess, _ListVoiceProfilesResponseSuccess, _PutSipMediaApplicationAlexaSkillConfigurationResponseSuccess, _PutSipMediaApplicationLoggingConfigurationResponseSuccess, _PutVoiceConnectorEmergencyCallingConfigurationResponseSuccess, _PutVoiceConnectorExternalSystemsConfigurationResponseSuccess, _PutVoiceConnectorLoggingConfigurationResponseSuccess, _PutVoiceConnectorOriginationResponseSuccess, _PutVoiceConnectorProxyResponseSuccess, _PutVoiceConnectorStreamingConfigurationResponseSuccess, _PutVoiceConnectorTerminationResponseSuccess, _RestorePhoneNumberResponseSuccess, _SearchAvailablePhoneNumbersResponseSuccess, _StartSpeakerSearchTaskResponseSuccess, _StartVoiceToneAnalysisTaskResponseSuccess, _UpdatePhoneNumberResponseSuccess, _UpdateProxySessionResponseSuccess, _UpdateSipMediaApplicationCallResponseSuccess, _UpdateSipMediaApplicationResponseSuccess, _UpdateSipRuleResponseSuccess, _UpdateVoiceConnectorGroupResponseSuccess, _UpdateVoiceConnectorResponseSuccess, _UpdateVoiceProfileDomainResponseSuccess, _UpdateVoiceProfileResponseSuccess, _ValidateE911AddressResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_phone_numbers_with_voice_connector(params = {}) ⇒ Types::AssociatePhoneNumbersWithVoiceConnectorResponse
Associates phone numbers with the specified Amazon Chime SDK Voice Connector.
-
#associate_phone_numbers_with_voice_connector_group(params = {}) ⇒ Types::AssociatePhoneNumbersWithVoiceConnectorGroupResponse
Associates phone numbers with the specified Amazon Chime SDK Voice Connector group.
-
#batch_delete_phone_number(params = {}) ⇒ Types::BatchDeletePhoneNumberResponse
Moves phone numbers into the Deletion queue.
-
#batch_update_phone_number(params = {}) ⇒ Types::BatchUpdatePhoneNumberResponse
Updates phone number product types, calling names, or phone number names.
-
#create_phone_number_order(params = {}) ⇒ Types::CreatePhoneNumberOrderResponse
Creates an order for phone numbers to be provisioned.
-
#create_proxy_session(params = {}) ⇒ Types::CreateProxySessionResponse
Creates a proxy session for the specified Amazon Chime SDK Voice Connector for the specified participant phone numbers.
-
#create_sip_media_application(params = {}) ⇒ Types::CreateSipMediaApplicationResponse
Creates a SIP media application.
-
#create_sip_media_application_call(params = {}) ⇒ Types::CreateSipMediaApplicationCallResponse
Creates an outbound call to a phone number from the phone number specified in the request, and it invokes the endpoint of the specified
sipMediaApplicationId. -
#create_sip_rule(params = {}) ⇒ Types::CreateSipRuleResponse
Creates a SIP rule, which can be used to run a SIP media application as a target for a specific trigger type.
-
#create_voice_connector(params = {}) ⇒ Types::CreateVoiceConnectorResponse
Creates an Amazon Chime SDK Voice Connector.
-
#create_voice_connector_group(params = {}) ⇒ Types::CreateVoiceConnectorGroupResponse
Creates an Amazon Chime SDK Voice Connector group under the administrator's AWS account.
-
#create_voice_profile(params = {}) ⇒ Types::CreateVoiceProfileResponse
Creates a voice profile, which consists of an enrolled user and their latest voice print.
-
#create_voice_profile_domain(params = {}) ⇒ Types::CreateVoiceProfileDomainResponse
Creates a voice profile domain, a collection of voice profiles, their voice prints, and encrypted enrollment audio.
-
#delete_phone_number(params = {}) ⇒ Struct
Moves the specified phone number into the Deletion queue.
-
#delete_proxy_session(params = {}) ⇒ Struct
Deletes the specified proxy session from the specified Amazon Chime SDK Voice Connector.
-
#delete_sip_media_application(params = {}) ⇒ Struct
Deletes a SIP media application.
-
#delete_sip_rule(params = {}) ⇒ Struct
Deletes a SIP rule.
-
#delete_voice_connector(params = {}) ⇒ Struct
Deletes an Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_emergency_calling_configuration(params = {}) ⇒ Struct
Deletes the emergency calling details from the specified Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_external_systems_configuration(params = {}) ⇒ Struct
Deletes the external systems configuration for a Voice Connector.
-
#delete_voice_connector_group(params = {}) ⇒ Struct
Deletes an Amazon Chime SDK Voice Connector group.
-
#delete_voice_connector_origination(params = {}) ⇒ Struct
Deletes the origination settings for the specified Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_proxy(params = {}) ⇒ Struct
Deletes the proxy configuration from the specified Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_streaming_configuration(params = {}) ⇒ Struct
Deletes a Voice Connector's streaming configuration.
-
#delete_voice_connector_termination(params = {}) ⇒ Struct
Deletes the termination settings for the specified Amazon Chime SDK Voice Connector.
-
#delete_voice_connector_termination_credentials(params = {}) ⇒ Struct
Deletes the specified SIP credentials used by your equipment to authenticate during call termination.
-
#delete_voice_profile(params = {}) ⇒ Struct
Deletes a voice profile, including its voice print and enrollment data.
-
#delete_voice_profile_domain(params = {}) ⇒ Struct
Deletes all voice profiles in the domain.
-
#disassociate_phone_numbers_from_voice_connector(params = {}) ⇒ Types::DisassociatePhoneNumbersFromVoiceConnectorResponse
Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector.
-
#disassociate_phone_numbers_from_voice_connector_group(params = {}) ⇒ Types::DisassociatePhoneNumbersFromVoiceConnectorGroupResponse
Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector group.
-
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsResponse
Retrieves the global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
-
#get_phone_number(params = {}) ⇒ Types::GetPhoneNumberResponse
Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.
-
#get_phone_number_order(params = {}) ⇒ Types::GetPhoneNumberOrderResponse
Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.
-
#get_phone_number_settings(params = {}) ⇒ Types::GetPhoneNumberSettingsResponse
Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.
-
#get_proxy_session(params = {}) ⇒ Types::GetProxySessionResponse
Retrieves the specified proxy session details for the specified Amazon Chime SDK Voice Connector.
-
#get_sip_media_application(params = {}) ⇒ Types::GetSipMediaApplicationResponse
Retrieves the information for a SIP media application, including name, AWS Region, and endpoints.
-
#get_sip_media_application_alexa_skill_configuration(params = {}) ⇒ Types::GetSipMediaApplicationAlexaSkillConfigurationResponse
Gets the Alexa Skill configuration for the SIP media application.
-
#get_sip_media_application_logging_configuration(params = {}) ⇒ Types::GetSipMediaApplicationLoggingConfigurationResponse
Retrieves the logging configuration for the specified SIP media application.
-
#get_sip_rule(params = {}) ⇒ Types::GetSipRuleResponse
Retrieves the details of a SIP rule, such as the rule ID, name, triggers, and target endpoints.
-
#get_speaker_search_task(params = {}) ⇒ Types::GetSpeakerSearchTaskResponse
Retrieves the details of the specified speaker search task.
-
#get_voice_connector(params = {}) ⇒ Types::GetVoiceConnectorResponse
Retrieves details for the specified Amazon Chime SDK Voice Connector, such as timestamps,name, outbound host, and encryption requirements.
-
#get_voice_connector_emergency_calling_configuration(params = {}) ⇒ Types::GetVoiceConnectorEmergencyCallingConfigurationResponse
Retrieves the emergency calling configuration details for the specified Voice Connector.
-
#get_voice_connector_external_systems_configuration(params = {}) ⇒ Types::GetVoiceConnectorExternalSystemsConfigurationResponse
Gets information about an external systems configuration for a Voice Connector.
-
#get_voice_connector_group(params = {}) ⇒ Types::GetVoiceConnectorGroupResponse
Retrieves details for the specified Amazon Chime SDK Voice Connector group, such as timestamps,name, and associated
VoiceConnectorItems. -
#get_voice_connector_logging_configuration(params = {}) ⇒ Types::GetVoiceConnectorLoggingConfigurationResponse
Retrieves the logging configuration settings for the specified Voice Connector.
-
#get_voice_connector_origination(params = {}) ⇒ Types::GetVoiceConnectorOriginationResponse
Retrieves the origination settings for the specified Voice Connector.
-
#get_voice_connector_proxy(params = {}) ⇒ Types::GetVoiceConnectorProxyResponse
Retrieves the proxy configuration details for the specified Amazon Chime SDK Voice Connector.
-
#get_voice_connector_streaming_configuration(params = {}) ⇒ Types::GetVoiceConnectorStreamingConfigurationResponse
Retrieves the streaming configuration details for the specified Amazon Chime SDK Voice Connector.
-
#get_voice_connector_termination(params = {}) ⇒ Types::GetVoiceConnectorTerminationResponse
Retrieves the termination setting details for the specified Voice Connector.
-
#get_voice_connector_termination_health(params = {}) ⇒ Types::GetVoiceConnectorTerminationHealthResponse
Retrieves information about the last time a
SIP OPTIONSping was received from your SIP infrastructure for the specified Amazon Chime SDK Voice Connector. -
#get_voice_profile(params = {}) ⇒ Types::GetVoiceProfileResponse
Retrieves the details of the specified voice profile.
-
#get_voice_profile_domain(params = {}) ⇒ Types::GetVoiceProfileDomainResponse
Retrieves the details of the specified voice profile domain.
-
#get_voice_tone_analysis_task(params = {}) ⇒ Types::GetVoiceToneAnalysisTaskResponse
Retrieves the details of a voice tone analysis task.
-
#list_available_voice_connector_regions(params = {}) ⇒ Types::ListAvailableVoiceConnectorRegionsResponse
Lists the available AWS Regions in which you can create an Amazon Chime SDK Voice Connector.
-
#list_phone_number_orders(params = {}) ⇒ Types::ListPhoneNumberOrdersResponse
Lists the phone numbers for an administrator's Amazon Chime SDK account.
-
#list_phone_numbers(params = {}) ⇒ Types::ListPhoneNumbersResponse
Lists the phone numbers for the specified Amazon Chime SDK account, Amazon Chime SDK user, Amazon Chime SDK Voice Connector, or Amazon Chime SDK Voice Connector group.
-
#list_proxy_sessions(params = {}) ⇒ Types::ListProxySessionsResponse
Lists the proxy sessions for the specified Amazon Chime SDK Voice Connector.
-
#list_sip_media_applications(params = {}) ⇒ Types::ListSipMediaApplicationsResponse
Lists the SIP media applications under the administrator's AWS account.
-
#list_sip_rules(params = {}) ⇒ Types::ListSipRulesResponse
Lists the SIP rules under the administrator's AWS account.
-
#list_supported_phone_number_countries(params = {}) ⇒ Types::ListSupportedPhoneNumberCountriesResponse
Lists the countries that you can order phone numbers from.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags in a given resource.
-
#list_voice_connector_groups(params = {}) ⇒ Types::ListVoiceConnectorGroupsResponse
Lists the Amazon Chime SDK Voice Connector groups in the administrator's AWS account.
-
#list_voice_connector_termination_credentials(params = {}) ⇒ Types::ListVoiceConnectorTerminationCredentialsResponse
Lists the SIP credentials for the specified Amazon Chime SDK Voice Connector.
-
#list_voice_connectors(params = {}) ⇒ Types::ListVoiceConnectorsResponse
Lists the Amazon Chime SDK Voice Connectors in the administrators AWS account.
-
#list_voice_profile_domains(params = {}) ⇒ Types::ListVoiceProfileDomainsResponse
Lists the specified voice profile domains in the administrator's AWS account.
-
#list_voice_profiles(params = {}) ⇒ Types::ListVoiceProfilesResponse
Lists the voice profiles in a voice profile domain.
-
#put_sip_media_application_alexa_skill_configuration(params = {}) ⇒ Types::PutSipMediaApplicationAlexaSkillConfigurationResponse
Updates the Alexa Skill configuration for the SIP media application.
-
#put_sip_media_application_logging_configuration(params = {}) ⇒ Types::PutSipMediaApplicationLoggingConfigurationResponse
Updates the logging configuration for the specified SIP media application.
-
#put_voice_connector_emergency_calling_configuration(params = {}) ⇒ Types::PutVoiceConnectorEmergencyCallingConfigurationResponse
Updates a Voice Connector's emergency calling configuration.
-
#put_voice_connector_external_systems_configuration(params = {}) ⇒ Types::PutVoiceConnectorExternalSystemsConfigurationResponse
Adds an external systems configuration to a Voice Connector.
-
#put_voice_connector_logging_configuration(params = {}) ⇒ Types::PutVoiceConnectorLoggingConfigurationResponse
Updates a Voice Connector's logging configuration.
-
#put_voice_connector_origination(params = {}) ⇒ Types::PutVoiceConnectorOriginationResponse
Updates a Voice Connector's origination settings.
-
#put_voice_connector_proxy(params = {}) ⇒ Types::PutVoiceConnectorProxyResponse
Puts the specified proxy configuration to the specified Amazon Chime SDK Voice Connector.
-
#put_voice_connector_streaming_configuration(params = {}) ⇒ Types::PutVoiceConnectorStreamingConfigurationResponse
Updates a Voice Connector's streaming configuration settings.
-
#put_voice_connector_termination(params = {}) ⇒ Types::PutVoiceConnectorTerminationResponse
Updates a Voice Connector's termination settings.
-
#put_voice_connector_termination_credentials(params = {}) ⇒ Struct
Updates a Voice Connector's termination credentials.
-
#restore_phone_number(params = {}) ⇒ Types::RestorePhoneNumberResponse
Restores a deleted phone number.
-
#search_available_phone_numbers(params = {}) ⇒ Types::SearchAvailablePhoneNumbersResponse
Searches the provisioned phone numbers in an organization.
-
#start_speaker_search_task(params = {}) ⇒ Types::StartSpeakerSearchTaskResponse
Starts a speaker search task.
-
#start_voice_tone_analysis_task(params = {}) ⇒ Types::StartVoiceToneAnalysisTaskResponse
Starts a voice tone analysis task.
-
#stop_speaker_search_task(params = {}) ⇒ Struct
Stops a speaker search task.
-
#stop_voice_tone_analysis_task(params = {}) ⇒ Struct
Stops a voice tone analysis task.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_global_settings(params = {}) ⇒ Struct
Updates global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
-
#update_phone_number(params = {}) ⇒ Types::UpdatePhoneNumberResponse
Updates phone number details, such as product type, calling name, or phone number name for the specified phone number ID.
-
#update_phone_number_settings(params = {}) ⇒ Struct
Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name.
-
#update_proxy_session(params = {}) ⇒ Types::UpdateProxySessionResponse
Updates the specified proxy session details, such as voice or SMS capabilities.
-
#update_sip_media_application(params = {}) ⇒ Types::UpdateSipMediaApplicationResponse
Updates the details of the specified SIP media application.
-
#update_sip_media_application_call(params = {}) ⇒ Types::UpdateSipMediaApplicationCallResponse
Invokes the AWS Lambda function associated with the SIP media application and transaction ID in an update request.
-
#update_sip_rule(params = {}) ⇒ Types::UpdateSipRuleResponse
Updates the details of the specified SIP rule.
-
#update_voice_connector(params = {}) ⇒ Types::UpdateVoiceConnectorResponse
Updates the details for the specified Amazon Chime SDK Voice Connector.
-
#update_voice_connector_group(params = {}) ⇒ Types::UpdateVoiceConnectorGroupResponse
Updates the settings for the specified Amazon Chime SDK Voice Connector group.
-
#update_voice_profile(params = {}) ⇒ Types::UpdateVoiceProfileResponse
Updates the specified voice profile’s voice print and refreshes its expiration timestamp.
-
#update_voice_profile_domain(params = {}) ⇒ Types::UpdateVoiceProfileDomainResponse
Updates the settings for the specified voice profile domain.
-
#validate_e911_address(params = {}) ⇒ Types::ValidateE911AddressResponse
Validates an address to be used for 911 calls made with Amazon Chime SDK Voice Connectors.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4465 4466 4467 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 4465 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4468 4469 4470 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 4468 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_phone_numbers_with_voice_connector(params = {}) ⇒ Types::AssociatePhoneNumbersWithVoiceConnectorResponse
Associates phone numbers with the specified Amazon Chime SDK Voice Connector.
86 |
# File 'sig/client.rbs', line 86
def associate_phone_numbers_with_voice_connector: (
|
#associate_phone_numbers_with_voice_connector_group(params = {}) ⇒ Types::AssociatePhoneNumbersWithVoiceConnectorGroupResponse
Associates phone numbers with the specified Amazon Chime SDK Voice Connector group.
98 |
# File 'sig/client.rbs', line 98
def associate_phone_numbers_with_voice_connector_group: (
|
#batch_delete_phone_number(params = {}) ⇒ Types::BatchDeletePhoneNumberResponse
Moves phone numbers into the Deletion queue. Phone numbers must be disassociated from any users or Amazon Chime SDK Voice Connectors before they can be deleted.
Phone numbers remain in the Deletion queue for 7 days before they are deleted permanently.
110 |
# File 'sig/client.rbs', line 110
def batch_delete_phone_number: (
|
#batch_update_phone_number(params = {}) ⇒ Types::BatchUpdatePhoneNumberResponse
Updates phone number product types, calling names, or phone number
names. You can update one attribute at a time for each
UpdatePhoneNumberRequestItem. For example, you can update the
product type, the calling name, or phone name.
phoneNumberId in a request.
120 |
# File 'sig/client.rbs', line 120
def batch_update_phone_number: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 4438 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ChimeSDKVoice') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chimesdkvoice' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#create_phone_number_order(params = {}) ⇒ Types::CreatePhoneNumberOrderResponse
Creates an order for phone numbers to be provisioned. For numbers outside the U.S., you must use the Amazon Chime SDK SIP media application dial-in product type.
137 |
# File 'sig/client.rbs', line 137
def create_phone_number_order: (
|
#create_proxy_session(params = {}) ⇒ Types::CreateProxySessionResponse
Creates a proxy session for the specified Amazon Chime SDK Voice Connector for the specified participant phone numbers.
149 |
# File 'sig/client.rbs', line 149
def create_proxy_session: (
|
#create_sip_media_application(params = {}) ⇒ Types::CreateSipMediaApplicationResponse
Creates a SIP media application. For more information about SIP media applications, see Managing SIP media applications and rules in the Amazon Chime SDK Administrator Guide.
169 |
# File 'sig/client.rbs', line 169
def create_sip_media_application: (
|
#create_sip_media_application_call(params = {}) ⇒ Types::CreateSipMediaApplicationCallResponse
Creates an outbound call to a phone number from the phone number
specified in the request, and it invokes the endpoint of the specified
sipMediaApplicationId.
191 |
# File 'sig/client.rbs', line 191
def create_sip_media_application_call: (
|
#create_sip_rule(params = {}) ⇒ Types::CreateSipRuleResponse
Creates a SIP rule, which can be used to run a SIP media application as a target for a specific trigger type. For more information about SIP rules, see Managing SIP media applications and rules in the Amazon Chime SDK Administrator Guide.
205 |
# File 'sig/client.rbs', line 205
def create_sip_rule: (
|
#create_voice_connector(params = {}) ⇒ Types::CreateVoiceConnectorResponse
Creates an Amazon Chime SDK Voice Connector. For more information about Voice Connectors, see Managing Amazon Chime SDK Voice Connector groups in the Amazon Chime SDK Administrator Guide.
225 |
# File 'sig/client.rbs', line 225
def create_voice_connector: (
|
#create_voice_connector_group(params = {}) ⇒ Types::CreateVoiceConnectorGroupResponse
Creates an Amazon Chime SDK Voice Connector group under the
administrator's AWS account. You can associate Amazon Chime SDK Voice
Connectors with the Voice Connector group by including
VoiceConnectorItems in the request.
You can include Voice Connectors from different AWS Regions in your group. This creates a fault tolerant mechanism for fallback in case of availability events.
245 |
# File 'sig/client.rbs', line 245
def create_voice_connector_group: (
|
#create_voice_profile(params = {}) ⇒ Types::CreateVoiceProfileResponse
Creates a voice profile, which consists of an enrolled user and their latest voice print.
Before creating any voice profiles, you must provide all notices and obtain all consents from the speaker as required under applicable privacy and biometrics laws, and as required under the AWS service terms for the Amazon Chime SDK.
For more information about voice profiles and voice analytics, see Using Amazon Chime SDK Voice Analytics in the Amazon Chime SDK Developer Guide.
261 |
# File 'sig/client.rbs', line 261
def create_voice_profile: (
|
#create_voice_profile_domain(params = {}) ⇒ Types::CreateVoiceProfileDomainResponse
Creates a voice profile domain, a collection of voice profiles, their voice prints, and encrypted enrollment audio.
Before creating any voice profiles, you must provide all notices and obtain all consents from the speaker as required under applicable privacy and biometrics laws, and as required under the AWS service terms for the Amazon Chime SDK.
For more information about voice profile domains, see Using Amazon Chime SDK Voice Analytics in the Amazon Chime SDK Developer Guide.
271 |
# File 'sig/client.rbs', line 271
def create_voice_profile_domain: (
|
#delete_phone_number(params = {}) ⇒ Struct
Moves the specified phone number into the Deletion queue. A phone number must be disassociated from any users or Amazon Chime SDK Voice Connectors before it can be deleted.
Deleted phone numbers remain in the Deletion queue queue for 7 days before they are deleted permanently.
288 |
# File 'sig/client.rbs', line 288
def delete_phone_number: (
|
#delete_proxy_session(params = {}) ⇒ Struct
Deletes the specified proxy session from the specified Amazon Chime SDK Voice Connector.
294 |
# File 'sig/client.rbs', line 294
def delete_proxy_session: (
|
#delete_sip_media_application(params = {}) ⇒ Struct
Deletes a SIP media application.
301 |
# File 'sig/client.rbs', line 301
def delete_sip_media_application: (
|
#delete_sip_rule(params = {}) ⇒ Struct
Deletes a SIP rule.
307 |
# File 'sig/client.rbs', line 307
def delete_sip_rule: (
|
#delete_voice_connector(params = {}) ⇒ Struct
Deletes an Amazon Chime SDK Voice Connector. Any phone numbers associated with the Amazon Chime SDK Voice Connector must be disassociated from it before it can be deleted.
313 |
# File 'sig/client.rbs', line 313
def delete_voice_connector: (
|
#delete_voice_connector_emergency_calling_configuration(params = {}) ⇒ Struct
Deletes the emergency calling details from the specified Amazon Chime SDK Voice Connector.
319 |
# File 'sig/client.rbs', line 319
def delete_voice_connector_emergency_calling_configuration: (
|
#delete_voice_connector_external_systems_configuration(params = {}) ⇒ Struct
Deletes the external systems configuration for a Voice Connector.
325 |
# File 'sig/client.rbs', line 325
def delete_voice_connector_external_systems_configuration: (
|
#delete_voice_connector_group(params = {}) ⇒ Struct
Deletes an Amazon Chime SDK Voice Connector group. Any
VoiceConnectorItems and phone numbers associated with the group must
be removed before it can be deleted.
331 |
# File 'sig/client.rbs', line 331
def delete_voice_connector_group: (
|
#delete_voice_connector_origination(params = {}) ⇒ Struct
Deletes the origination settings for the specified Amazon Chime SDK Voice Connector.
337 |
# File 'sig/client.rbs', line 337
def delete_voice_connector_origination: (
|
#delete_voice_connector_proxy(params = {}) ⇒ Struct
Deletes the proxy configuration from the specified Amazon Chime SDK Voice Connector.
343 |
# File 'sig/client.rbs', line 343
def delete_voice_connector_proxy: (
|
#delete_voice_connector_streaming_configuration(params = {}) ⇒ Struct
Deletes a Voice Connector's streaming configuration.
349 |
# File 'sig/client.rbs', line 349
def delete_voice_connector_streaming_configuration: (
|
#delete_voice_connector_termination(params = {}) ⇒ Struct
Deletes the termination settings for the specified Amazon Chime SDK Voice Connector.
355 |
# File 'sig/client.rbs', line 355
def delete_voice_connector_termination: (
|
#delete_voice_connector_termination_credentials(params = {}) ⇒ Struct
Deletes the specified SIP credentials used by your equipment to authenticate during call termination.
361 |
# File 'sig/client.rbs', line 361
def delete_voice_connector_termination_credentials: (
|
#delete_voice_profile(params = {}) ⇒ Struct
Deletes a voice profile, including its voice print and enrollment data. WARNING: This action is not reversible.
368 |
# File 'sig/client.rbs', line 368
def delete_voice_profile: (
|
#delete_voice_profile_domain(params = {}) ⇒ Struct
Deletes all voice profiles in the domain. WARNING: This action is not reversible.
374 |
# File 'sig/client.rbs', line 374
def delete_voice_profile_domain: (
|
#disassociate_phone_numbers_from_voice_connector(params = {}) ⇒ Types::DisassociatePhoneNumbersFromVoiceConnectorResponse
Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector.
384 |
# File 'sig/client.rbs', line 384
def disassociate_phone_numbers_from_voice_connector: (
|
#disassociate_phone_numbers_from_voice_connector_group(params = {}) ⇒ Types::DisassociatePhoneNumbersFromVoiceConnectorGroupResponse
Disassociates the specified phone numbers from the specified Amazon Chime SDK Voice Connector group.
395 |
# File 'sig/client.rbs', line 395
def disassociate_phone_numbers_from_voice_connector_group: (
|
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsResponse
Retrieves the global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
406 407 |
# File 'sig/client.rbs', line 406
def get_global_settings: () -> _GetGlobalSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetGlobalSettingsResponseSuccess
|
#get_phone_number(params = {}) ⇒ Types::GetPhoneNumberResponse
Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.
414 |
# File 'sig/client.rbs', line 414
def get_phone_number: (
|
#get_phone_number_order(params = {}) ⇒ Types::GetPhoneNumberOrderResponse
Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.
424 |
# File 'sig/client.rbs', line 424
def get_phone_number_order: (
|
#get_phone_number_settings(params = {}) ⇒ Types::GetPhoneNumberSettingsResponse
Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.
435 436 |
# File 'sig/client.rbs', line 435
def get_phone_number_settings: () -> _GetPhoneNumberSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetPhoneNumberSettingsResponseSuccess
|
#get_proxy_session(params = {}) ⇒ Types::GetProxySessionResponse
Retrieves the specified proxy session details for the specified Amazon Chime SDK Voice Connector.
443 |
# File 'sig/client.rbs', line 443
def get_proxy_session: (
|
#get_sip_media_application(params = {}) ⇒ Types::GetSipMediaApplicationResponse
Retrieves the information for a SIP media application, including name, AWS Region, and endpoints.
454 |
# File 'sig/client.rbs', line 454
def get_sip_media_application: (
|
#get_sip_media_application_alexa_skill_configuration(params = {}) ⇒ Types::GetSipMediaApplicationAlexaSkillConfigurationResponse
Gets the Alexa Skill configuration for the SIP media application.
Due to changes made by the Amazon Alexa service, this API is no longer available for use. For more information, refer to the Alexa Smart Properties page.
464 |
# File 'sig/client.rbs', line 464
def get_sip_media_application_alexa_skill_configuration: (
|
#get_sip_media_application_logging_configuration(params = {}) ⇒ Types::GetSipMediaApplicationLoggingConfigurationResponse
Retrieves the logging configuration for the specified SIP media application.
474 |
# File 'sig/client.rbs', line 474
def get_sip_media_application_logging_configuration: (
|
#get_sip_rule(params = {}) ⇒ Types::GetSipRuleResponse
Retrieves the details of a SIP rule, such as the rule ID, name, triggers, and target endpoints.
484 |
# File 'sig/client.rbs', line 484
def get_sip_rule: (
|
#get_speaker_search_task(params = {}) ⇒ Types::GetSpeakerSearchTaskResponse
Retrieves the details of the specified speaker search task.
494 |
# File 'sig/client.rbs', line 494
def get_speaker_search_task: (
|
#get_voice_connector(params = {}) ⇒ Types::GetVoiceConnectorResponse
Retrieves details for the specified Amazon Chime SDK Voice Connector, such as timestamps,name, outbound host, and encryption requirements.
505 |
# File 'sig/client.rbs', line 505
def get_voice_connector: (
|
#get_voice_connector_emergency_calling_configuration(params = {}) ⇒ Types::GetVoiceConnectorEmergencyCallingConfigurationResponse
Retrieves the emergency calling configuration details for the specified Voice Connector.
515 |
# File 'sig/client.rbs', line 515
def get_voice_connector_emergency_calling_configuration: (
|
#get_voice_connector_external_systems_configuration(params = {}) ⇒ Types::GetVoiceConnectorExternalSystemsConfigurationResponse
Gets information about an external systems configuration for a Voice Connector.
525 |
# File 'sig/client.rbs', line 525
def get_voice_connector_external_systems_configuration: (
|
#get_voice_connector_group(params = {}) ⇒ Types::GetVoiceConnectorGroupResponse
Retrieves details for the specified Amazon Chime SDK Voice Connector
group, such as timestamps,name, and associated VoiceConnectorItems.
535 |
# File 'sig/client.rbs', line 535
def get_voice_connector_group: (
|
#get_voice_connector_logging_configuration(params = {}) ⇒ Types::GetVoiceConnectorLoggingConfigurationResponse
Retrieves the logging configuration settings for the specified Voice Connector. Shows whether SIP message logs are enabled for sending to Amazon CloudWatch Logs.
545 |
# File 'sig/client.rbs', line 545
def get_voice_connector_logging_configuration: (
|
#get_voice_connector_origination(params = {}) ⇒ Types::GetVoiceConnectorOriginationResponse
Retrieves the origination settings for the specified Voice Connector.
555 |
# File 'sig/client.rbs', line 555
def get_voice_connector_origination: (
|
#get_voice_connector_proxy(params = {}) ⇒ Types::GetVoiceConnectorProxyResponse
Retrieves the proxy configuration details for the specified Amazon Chime SDK Voice Connector.
565 |
# File 'sig/client.rbs', line 565
def get_voice_connector_proxy: (
|
#get_voice_connector_streaming_configuration(params = {}) ⇒ Types::GetVoiceConnectorStreamingConfigurationResponse
Retrieves the streaming configuration details for the specified Amazon Chime SDK Voice Connector. Shows whether media streaming is enabled for sending to Amazon Kinesis. It also shows the retention period, in hours, for the Amazon Kinesis data.
575 |
# File 'sig/client.rbs', line 575
def get_voice_connector_streaming_configuration: (
|
#get_voice_connector_termination(params = {}) ⇒ Types::GetVoiceConnectorTerminationResponse
Retrieves the termination setting details for the specified Voice Connector.
585 |
# File 'sig/client.rbs', line 585
def get_voice_connector_termination: (
|
#get_voice_connector_termination_health(params = {}) ⇒ Types::GetVoiceConnectorTerminationHealthResponse
Retrieves information about the last time a SIP OPTIONS ping was
received from your SIP infrastructure for the specified Amazon Chime
SDK Voice Connector.
595 |
# File 'sig/client.rbs', line 595
def get_voice_connector_termination_health: (
|
#get_voice_profile(params = {}) ⇒ Types::GetVoiceProfileResponse
Retrieves the details of the specified voice profile.
605 |
# File 'sig/client.rbs', line 605
def get_voice_profile: (
|
#get_voice_profile_domain(params = {}) ⇒ Types::GetVoiceProfileDomainResponse
Retrieves the details of the specified voice profile domain.
615 |
# File 'sig/client.rbs', line 615
def get_voice_profile_domain: (
|
#get_voice_tone_analysis_task(params = {}) ⇒ Types::GetVoiceToneAnalysisTaskResponse
Retrieves the details of a voice tone analysis task.
625 |
# File 'sig/client.rbs', line 625
def get_voice_tone_analysis_task: (
|
#list_available_voice_connector_regions(params = {}) ⇒ Types::ListAvailableVoiceConnectorRegionsResponse
Lists the available AWS Regions in which you can create an Amazon Chime SDK Voice Connector.
637 638 |
# File 'sig/client.rbs', line 637
def list_available_voice_connector_regions: () -> _ListAvailableVoiceConnectorRegionsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _ListAvailableVoiceConnectorRegionsResponseSuccess
|
#list_phone_number_orders(params = {}) ⇒ Types::ListPhoneNumberOrdersResponse
Lists the phone numbers for an administrator's Amazon Chime SDK account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
646 |
# File 'sig/client.rbs', line 646
def list_phone_number_orders: (
|
#list_phone_numbers(params = {}) ⇒ Types::ListPhoneNumbersResponse
Lists the phone numbers for the specified Amazon Chime SDK account, Amazon Chime SDK user, Amazon Chime SDK Voice Connector, or Amazon Chime SDK Voice Connector group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
658 |
# File 'sig/client.rbs', line 658
def list_phone_numbers: (
|
#list_proxy_sessions(params = {}) ⇒ Types::ListProxySessionsResponse
Lists the proxy sessions for the specified Amazon Chime SDK Voice Connector.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
674 |
# File 'sig/client.rbs', line 674
def list_proxy_sessions: (
|
#list_sip_media_applications(params = {}) ⇒ Types::ListSipMediaApplicationsResponse
Lists the SIP media applications under the administrator's AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
688 |
# File 'sig/client.rbs', line 688
def list_sip_media_applications: (
|
#list_sip_rules(params = {}) ⇒ Types::ListSipRulesResponse
Lists the SIP rules under the administrator's AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
700 |
# File 'sig/client.rbs', line 700
def list_sip_rules: (
|
#list_supported_phone_number_countries(params = {}) ⇒ Types::ListSupportedPhoneNumberCountriesResponse
Lists the countries that you can order phone numbers from.
712 |
# File 'sig/client.rbs', line 712
def list_supported_phone_number_countries: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags in a given resource.
722 |
# File 'sig/client.rbs', line 722
def list_tags_for_resource: (
|
#list_voice_connector_groups(params = {}) ⇒ Types::ListVoiceConnectorGroupsResponse
Lists the Amazon Chime SDK Voice Connector groups in the administrator's AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
733 |
# File 'sig/client.rbs', line 733
def list_voice_connector_groups: (
|
#list_voice_connector_termination_credentials(params = {}) ⇒ Types::ListVoiceConnectorTerminationCredentialsResponse
Lists the SIP credentials for the specified Amazon Chime SDK Voice Connector.
744 |
# File 'sig/client.rbs', line 744
def list_voice_connector_termination_credentials: (
|
#list_voice_connectors(params = {}) ⇒ Types::ListVoiceConnectorsResponse
Lists the Amazon Chime SDK Voice Connectors in the administrators AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
755 |
# File 'sig/client.rbs', line 755
def list_voice_connectors: (
|
#list_voice_profile_domains(params = {}) ⇒ Types::ListVoiceProfileDomainsResponse
Lists the specified voice profile domains in the administrator's AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
767 |
# File 'sig/client.rbs', line 767
def list_voice_profile_domains: (
|
#list_voice_profiles(params = {}) ⇒ Types::ListVoiceProfilesResponse
Lists the voice profiles in a voice profile domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
779 |
# File 'sig/client.rbs', line 779
def list_voice_profiles: (
|
#put_sip_media_application_alexa_skill_configuration(params = {}) ⇒ Types::PutSipMediaApplicationAlexaSkillConfigurationResponse
Updates the Alexa Skill configuration for the SIP media application.
Due to changes made by the Amazon Alexa service, this API is no longer available for use. For more information, refer to the Alexa Smart Properties page.
791 |
# File 'sig/client.rbs', line 791
def put_sip_media_application_alexa_skill_configuration: (
|
#put_sip_media_application_logging_configuration(params = {}) ⇒ Types::PutSipMediaApplicationLoggingConfigurationResponse
Updates the logging configuration for the specified SIP media application.
805 |
# File 'sig/client.rbs', line 805
def put_sip_media_application_logging_configuration: (
|
#put_voice_connector_emergency_calling_configuration(params = {}) ⇒ Types::PutVoiceConnectorEmergencyCallingConfigurationResponse
Updates a Voice Connector's emergency calling configuration.
818 |
# File 'sig/client.rbs', line 818
def put_voice_connector_emergency_calling_configuration: (
|
#put_voice_connector_external_systems_configuration(params = {}) ⇒ Types::PutVoiceConnectorExternalSystemsConfigurationResponse
Adds an external systems configuration to a Voice Connector.
837 |
# File 'sig/client.rbs', line 837
def put_voice_connector_external_systems_configuration: (
|
#put_voice_connector_logging_configuration(params = {}) ⇒ Types::PutVoiceConnectorLoggingConfigurationResponse
Updates a Voice Connector's logging configuration.
849 |
# File 'sig/client.rbs', line 849
def put_voice_connector_logging_configuration: (
|
#put_voice_connector_origination(params = {}) ⇒ Types::PutVoiceConnectorOriginationResponse
Updates a Voice Connector's origination settings.
863 |
# File 'sig/client.rbs', line 863
def put_voice_connector_origination: (
|
#put_voice_connector_proxy(params = {}) ⇒ Types::PutVoiceConnectorProxyResponse
Puts the specified proxy configuration to the specified Amazon Chime SDK Voice Connector.
885 |
# File 'sig/client.rbs', line 885
def put_voice_connector_proxy: (
|
#put_voice_connector_streaming_configuration(params = {}) ⇒ Types::PutVoiceConnectorStreamingConfigurationResponse
Updates a Voice Connector's streaming configuration settings.
899 |
# File 'sig/client.rbs', line 899
def put_voice_connector_streaming_configuration: (
|
#put_voice_connector_termination(params = {}) ⇒ Types::PutVoiceConnectorTerminationResponse
Updates a Voice Connector's termination settings.
922 |
# File 'sig/client.rbs', line 922
def put_voice_connector_termination: (
|
#put_voice_connector_termination_credentials(params = {}) ⇒ Struct
Updates a Voice Connector's termination credentials.
935 |
# File 'sig/client.rbs', line 935
def put_voice_connector_termination_credentials: (
|
#restore_phone_number(params = {}) ⇒ Types::RestorePhoneNumberResponse
Restores a deleted phone number.
951 |
# File 'sig/client.rbs', line 951
def restore_phone_number: (
|
#search_available_phone_numbers(params = {}) ⇒ Types::SearchAvailablePhoneNumbersResponse
Searches the provisioned phone numbers in an organization.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
962 |
# File 'sig/client.rbs', line 962
def search_available_phone_numbers: (
|
#start_speaker_search_task(params = {}) ⇒ Types::StartSpeakerSearchTaskResponse
Starts a speaker search task.
Before starting any speaker search tasks, you must provide all notices and obtain all consents from the speaker as required under applicable privacy and biometrics laws, and as required under the AWS service terms for the Amazon Chime SDK.
979 |
# File 'sig/client.rbs', line 979
def start_speaker_search_task: (
|
#start_voice_tone_analysis_task(params = {}) ⇒ Types::StartVoiceToneAnalysisTaskResponse
Starts a voice tone analysis task. For more information about voice tone analysis, see Using Amazon Chime SDK voice analytics in the Amazon Chime SDK Developer Guide.
Before starting any voice tone analysis tasks, you must provide all notices and obtain all consents from the speaker as required under applicable privacy and biometrics laws, and as required under the AWS service terms for the Amazon Chime SDK.
993 |
# File 'sig/client.rbs', line 993
def start_voice_tone_analysis_task: (
|
#stop_speaker_search_task(params = {}) ⇒ Struct
Stops a speaker search task.
1002 |
# File 'sig/client.rbs', line 1002
def stop_speaker_search_task: (
|
#stop_voice_tone_analysis_task(params = {}) ⇒ Struct
Stops a voice tone analysis task.
1009 |
# File 'sig/client.rbs', line 1009
def stop_voice_tone_analysis_task: (
|
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
1016 |
# File 'sig/client.rbs', line 1016
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
1028 |
# File 'sig/client.rbs', line 1028
def untag_resource: (
|
#update_global_settings(params = {}) ⇒ Struct
Updates global settings for the Amazon Chime SDK Voice Connectors in an AWS account.
1035 |
# File 'sig/client.rbs', line 1035
def update_global_settings: (
|
#update_phone_number(params = {}) ⇒ Types::UpdatePhoneNumberResponse
Updates phone number details, such as product type, calling name, or phone number name for the specified phone number ID. You can update one phone number detail at a time. For example, you can update either the product type, calling name, or phone number name in one action.
For numbers outside the U.S., you must use the Amazon Chime SDK SIP Media Application Dial-In product type.
Updates to outbound calling names can take 72 hours to complete. Pending updates to outbound calling names must be complete before you can request another update.
1047 |
# File 'sig/client.rbs', line 1047
def update_phone_number: (
|
#update_phone_number_settings(params = {}) ⇒ Struct
Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name. You can update the default outbound calling name once every seven days. Outbound calling names can take up to 72 hours to update.
1056 |
# File 'sig/client.rbs', line 1056
def update_phone_number_settings: (
|
#update_proxy_session(params = {}) ⇒ Types::UpdateProxySessionResponse
Updates the specified proxy session details, such as voice or SMS capabilities.
1066 |
# File 'sig/client.rbs', line 1066
def update_proxy_session: (
|
#update_sip_media_application(params = {}) ⇒ Types::UpdateSipMediaApplicationResponse
Updates the details of the specified SIP media application.
1079 |
# File 'sig/client.rbs', line 1079
def update_sip_media_application: (
|
#update_sip_media_application_call(params = {}) ⇒ Types::UpdateSipMediaApplicationCallResponse
Invokes the AWS Lambda function associated with the SIP media application and transaction ID in an update request. The Lambda function can then return a new set of actions.
1095 |
# File 'sig/client.rbs', line 1095
def update_sip_media_application_call: (
|
#update_sip_rule(params = {}) ⇒ Types::UpdateSipRuleResponse
Updates the details of the specified SIP rule.
1107 |
# File 'sig/client.rbs', line 1107
def update_sip_rule: (
|
#update_voice_connector(params = {}) ⇒ Types::UpdateVoiceConnectorResponse
Updates the details for the specified Amazon Chime SDK Voice Connector.
1126 |
# File 'sig/client.rbs', line 1126
def update_voice_connector: (
|
#update_voice_connector_group(params = {}) ⇒ Types::UpdateVoiceConnectorGroupResponse
Updates the settings for the specified Amazon Chime SDK Voice Connector group.
1138 |
# File 'sig/client.rbs', line 1138
def update_voice_connector_group: (
|
#update_voice_profile(params = {}) ⇒ Types::UpdateVoiceProfileResponse
Updates the specified voice profile’s voice print and refreshes its expiration timestamp.
As a condition of using this feature, you acknowledge that the collection, use, storage, and retention of your caller’s biometric identifiers and biometric information (“biometric data”) in the form of a digital voiceprint requires the caller’s informed consent via a written release. Such consent is required under various state laws, including biometrics laws in Illinois, Texas, Washington and other state privacy laws.
You must provide a written release to each caller through a process that clearly reflects each caller’s informed consent before using Amazon Chime SDK Voice Insights service, as required under the terms of your agreement with AWS governing your use of the service.
1155 |
# File 'sig/client.rbs', line 1155
def update_voice_profile: (
|
#update_voice_profile_domain(params = {}) ⇒ Types::UpdateVoiceProfileDomainResponse
Updates the settings for the specified voice profile domain.
1166 |
# File 'sig/client.rbs', line 1166
def update_voice_profile_domain: (
|
#validate_e911_address(params = {}) ⇒ Types::ValidateE911AddressResponse
Validates an address to be used for 911 calls made with Amazon Chime SDK Voice Connectors. You can use validated addresses in a Presence Information Data Format Location Object file that you include in SIP requests. That helps ensure that addresses are routed to the appropriate Public Safety Answering Point.
1181 |
# File 'sig/client.rbs', line 1181
def validate_e911_address: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4458 4459 4460 |
# File 'lib/aws-sdk-chimesdkvoice/client.rb', line 4458 def waiter_names [] end |